#!/bin/bash

KCADM=${KEYCLOAK_HOME}/bin/kcadm.sh

#
# Set the requirement value for a particular flow's
# execution 
#
# Expected parameters:
# $1 - The authentication flow alias
# $2 - The execution identifier
# $3 - The required value
#
function setAuthFlowExecutionRequirement {
	echo "Setting execution with id $2 in flow $1 to $3..."
	${KCADM} get authentication/flows/$1/executions -r ${REALM_NAME} | \
		jq --arg exec_id $2 --arg requirement $3 'map(select(.id | contains($exec_id))) | .[0] | .requirement |= $requirement' | \
		${KCADM} update authentication/flows/$1/executions -r ${REALM_NAME} -n -f - 
}

#
# Create a new browser authentication flow that will capture the partner
# code for the user's authentication session.  Add the necessary execution script
# to the end of the flow.
#
echo "Creating copy of Browser flow"
${KCADM} create authentication/flows/browser/copy --id -r ${REALM_NAME} -s newName="BrowserCapturePartnerCode"

echo "Adding script authenticator to browser flow..."
SCRIPT_EXEC_ID=`${KCADM} create authentication/flows/BrowserCapturePartnerCode/executions/execution --id -r ${REALM_NAME} -s provider=auth-script-based`
setAuthFlowExecutionRequirement BrowserCapturePartnerCode $SCRIPT_EXEC_ID REQUIRED

echo "Configuring script authenticator in browser flow..."
PARTNER_CODE_AUTH_JS=`cat $BV_HOME/configuration/authenticators/partner_code.js`
jq -n --arg code "$PARTNER_CODE_AUTH_JS" '{ config: { scriptName: "BrowserCapturePartnerCode", scriptDescription: "Browser Capture Partner Code", scriptCode: $code }, alias: "browser-capture-partner-code" }' | \
	${KCADM} create authentication/executions/$SCRIPT_EXEC_ID/config -r ${REALM_NAME} -f -

#
# Create a new direct authentication flow that will capture the partner
# code for the user's authentication session.  Add the necessary execution script
# to the end of the flow.
#
echo "Creating copy of direct flow"
${KCADM} create authentication/flows/direct%20grant/copy --id -r ${REALM_NAME} -s newName="DirectCapturePartnerCode"

echo "Adding script authenticator to direct flow..."
SCRIPT_EXEC_ID=`${KCADM} create authentication/flows/DirectCapturePartnerCode/executions/execution --id -r ${REALM_NAME} -s provider=auth-script-based`
setAuthFlowExecutionRequirement DirectCapturePartnerCode $SCRIPT_EXEC_ID REQUIRED

echo "Configuring script authenticator in direct flow..."
jq -n --arg code "$PARTNER_CODE_AUTH_JS" '{ config: { scriptName: "DirectCapturePartnerCode", scriptDescription: "Direct Capture Partner Code", scriptCode: $code }, alias: "direct-capture-partner-code" }' | \
	${KCADM} create authentication/executions/$SCRIPT_EXEC_ID/config -r ${REALM_NAME} -f -

